==> redshift-0.10.0-sources.jar: software/amazon/awscdk/services/redshift/cloudformation/ClusterSecurityGroupResourceProps.java <==
package software.amazon.awscdk.services.redshift.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:43:53.423Z")
public interface ClusterSecurityGroupResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
     */
    java.lang.Object getDescription();
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
     */
    void setDescription(final java.lang.String value);
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
     */
    void setDescription(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
     */
    java.lang.Object getTags();
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
     */
    void setTags(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
     */
    void setTags(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link ClusterSecurityGroupResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ClusterSecurityGroupResourceProps}
     */
    final class Builder {
        private java.lang.Object _description;
        @javax.annotation.Nullable
        private java.lang.Object _tags;

        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterSecurityGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final java.lang.String value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterSecurityGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final software.amazon.awscdk.CloudFormationToken value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterSecurityGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._tags = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterSecurityGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ClusterSecurityGroupResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ClusterSecurityGroupResourceProps build() {
            return new ClusterSecurityGroupResourceProps() {
                private java.lang.Object $description = java.util.Objects.requireNonNull(_description, "description is required");
                @javax.annotation.Nullable
                private java.lang.Object $tags = _tags;

                @Override
                public java.lang.Object getDescription() {
                    return this.$description;
                }

                @Override
                public void setDescription(final java.lang.String value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public void setDescription(final software.amazon.awscdk.CloudFormationToken value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public java.lang.Object getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$tags = value;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.cloudformation.ClusterSecurityGroupResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
         */
        @Override
        public java.lang.Object getDescription() {
            return this.jsiiGet("description", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
         */
        @Override
        public void setDescription(final java.lang.String value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
         */
        @Override
        public void setDescription(final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getTags() {
            return this.jsiiGet("tags", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("tags", value);
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("tags", value);
        }
    }
}

==> redshift-0.11.0-sources.jar: software/amazon/awscdk/services/redshift/cloudformation/ClusterSecurityGroupResourceProps.java <==
package software.amazon.awscdk.services.redshift.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.7 (build b1c202b)", date = "2018-10-11T17:59:22.549Z")
public interface ClusterSecurityGroupResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
     */
    java.lang.Object getDescription();
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
     */
    void setDescription(final java.lang.String value);
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
     */
    void setDescription(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
     */
    java.lang.Object getTags();
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
     */
    void setTags(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::Redshift::ClusterSecurityGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
     */
    void setTags(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link ClusterSecurityGroupResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ClusterSecurityGroupResourceProps}
     */
    final class Builder {
        private java.lang.Object _description;
        @javax.annotation.Nullable
        private java.lang.Object _tags;

        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterSecurityGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final java.lang.String value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterSecurityGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final software.amazon.awscdk.Token value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterSecurityGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._tags = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterSecurityGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ClusterSecurityGroupResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ClusterSecurityGroupResourceProps build() {
            return new ClusterSecurityGroupResourceProps() {
                private java.lang.Object $description = java.util.Objects.requireNonNull(_description, "description is required");
                @javax.annotation.Nullable
                private java.lang.Object $tags = _tags;

                @Override
                public java.lang.Object getDescription() {
                    return this.$description;
                }

                @Override
                public void setDescription(final java.lang.String value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public void setDescription(final software.amazon.awscdk.Token value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public java.lang.Object getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$tags = value;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.cloudformation.ClusterSecurityGroupResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
         */
        @Override
        public java.lang.Object getDescription() {
            return this.jsiiGet("description", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
         */
        @Override
        public void setDescription(final java.lang.String value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-description
         */
        @Override
        public void setDescription(final software.amazon.awscdk.Token value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getTags() {
            return this.jsiiGet("tags", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("tags", value);
        }

        /**
         * ``AWS::Redshift::ClusterSecurityGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersecuritygroup.html#cfn-redshift-clustersecuritygroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("tags", value);
        }
    }
}
